@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,11 @@
 #include <QListWidgetItem>
 #include <QPointer>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 using namespace QKeychain;
 ServerSieveListWidget::ServerSieveListWidget(QWidget *parent)
     : QListWidget(parent)
@@ -21,9 +25,7 @@ ServerSieveListWidget::ServerSieveListWidget(QWidget *parent)
     connect(this, &ServerSieveListWidget::itemDoubleClicked, this, &ServerSieveListWidget::modifyServerConfig);
 }
 
-ServerSieveListWidget::~ServerSieveListWidget()
-{
-}
+ServerSieveListWidget::~ServerSieveListWidget() = default;
 
 void ServerSieveListWidget::readConfig()
 {
@@ -112,9 +114,7 @@ ServerSieveListWidgetItem::ServerSieveListWidgetItem(QListWidget *parent)
 {
 }
 
-ServerSieveListWidgetItem::~ServerSieveListWidgetItem()
-{
-}
+ServerSieveListWidgetItem::~ServerSieveListWidgetItem() = default;
 
 SieveEditorUtil::SieveServerConfig ServerSieveListWidgetItem::serverConfig() const
 {
